@@ -62,7 +62,7 @@ extends TestCase implements TelnetNotificationHandler
     private TestConnection ANSI;
     private TestConnection NOREAD;
 
-    private int NUM_CONNECTIONS = 4;
+    private final int NUM_CONNECTIONS = 4;
 
 
     protected int numdo = 0;
@@ -756,6 +756,7 @@ extends TestCase implements TelnetNotificationHandler
         assertTrue(test1spy_ok);
         assertTrue(test2spy_ok);
         assertTrue(stopspy_ok);
+        pi.close();
     }
 
     /***
@@ -879,6 +880,7 @@ extends TestCase implements TelnetNotificationHandler
      * @param option_code - code of the option negotiated
      * <p>
      ***/
+//    @Override
     public void receivedNegotiation(int negotiation_code, int option_code)
     {
         if(negotiation_code == TelnetNotificationHandler.RECEIVED_DO)
